Documentation
¶
Overview ¶
Package version reports the version of the lsqlited daemon.
Versions follow HeadVer (https://github.com/line/headver): {head}.{yearweek}.{build}, baked in at build time with
go build -ldflags "-X github.com/chiwanpark/lsqlited/internal/version.version=1.2534.7"
Index ¶
Constants ¶
const DriverName = "sqlite3_lsqlited"
DriverName is a database/sql driver equivalent to the stock "sqlite3" one, plus FuncName.
const FuncName = "lsqlited_version"
FuncName is the SQL function reporting the version of the daemon executing the query.
Variables ¶
This section is empty.
Functions ¶
func Register ¶
func Register(conn *sqlite3.SQLiteConn) error
Register makes FuncName available on conn.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.